@@ -11,7 +11,6 @@ use crate::recycler::Recycler;
 use rayon::ThreadPool;
 use solana_metrics::inc_new_counter_debug;
 use solana_rayon_threadlimit::get_thread_count;
-use solana_sdk::hash::Hash;
 use solana_sdk::message::MESSAGE_HEADER_LENGTH;
 use solana_sdk::pubkey::Pubkey;
 use solana_sdk::short_vec::decode_shortu16_len;
@@ -46,23 +45,15 @@ struct PacketOffsets {
     pub sig_start: u32,
     pub msg_start: u32,
     pub pubkey_start: u32,
-    pub pubkey_len: u32,
 }
 
 impl PacketOffsets {
-    pub fn new(
-        sig_len: u32,
-        sig_start: u32,
-        msg_start: u32,
-        pubkey_start: u32,
-        pubkey_len: u32,
-    ) -> Self {
+    pub fn new(sig_len: u32, sig_start: u32, msg_start: u32, pubkey_start: u32) -> Self {
         Self {
             sig_len,
             sig_start,
             msg_start,
             pubkey_start,
-            pubkey_len,
         }
     }
 }
@@ -75,8 +66,6 @@ pub enum PacketError {
     InvalidSignatureLen,
     MismatchSignatureLen,
     PayerNotWritable,
-    InvalidProgramIdIndex,
-    InvalidProgramLen,
 }
 
 impl std::convert::From<std::boxed::Box<bincode::ErrorKind>> for PacketError {
@@ -129,8 +118,10 @@ fn verify_packet(packet: &mut Packet) {
         let pubkey_end = pubkey_start.saturating_add(size_of::<Pubkey>());
         let sig_end = sig_start.saturating_add(size_of::<Signature>());
 
-        // get_packet_offsets should ensure pubkey_end and sig_end do
-        // not overflow packet.meta.size
+        if pubkey_end >= packet.meta.size || sig_end >= packet.meta.size {
+            packet.meta.discard = true;
+            return;
+        }
 
         let signature = Signature::new(&packet.data[sig_start..sig_end]);
 
@@ -226,10 +217,6 @@ fn do_get_packet_offsets(
         .filter(|v| *v <= packet.meta.size)
         .ok_or(PacketError::InvalidPubkeyLen)?;
 
-    if pubkey_len < sig_len_untrusted {
-        return Err(PacketError::InvalidPubkeyLen);
-    }
-
     let sig_start = current_offset
         .checked_add(sig_size)
         .ok_or(PacketError::InvalidLen)?;
@@ -245,104 +232,34 @@ fn do_get_packet_offsets(
         u32::try_from(sig_start)?,
         u32::try_from(msg_start)?,
         u32::try_from(pubkey_start)?,
-        u32::try_from(pubkey_len)?,
     ))
 }
 
-fn get_packet_offsets(packet: &mut Packet, current_offset: usize) -> PacketOffsets {
+fn get_packet_offsets(packet: &Packet, current_offset: usize) -> PacketOffsets {
     let unsanitized_packet_offsets = do_get_packet_offsets(packet, current_offset);
     if let Ok(offsets) = unsanitized_packet_offsets {
-        check_for_simple_vote_transaction(packet, &offsets, current_offset).ok();
         offsets
     } else {
         // force sigverify to fail by returning zeros
-        PacketOffsets::new(0, 0, 0, 0, 0)
+        PacketOffsets::new(0, 0, 0, 0)
     }
 }
 
-fn check_for_simple_vote_transaction(
-    packet: &mut Packet,
-    packet_offsets: &PacketOffsets,
-    current_offset: usize,
-) -> Result<(), PacketError> {
-    // vote could have 1 or 2 sigs; zero sig has already been excluded at
-    // do_get_packet_offsets.
-    if packet_offsets.sig_len > 2 {
-        return Err(PacketError::InvalidSignatureLen);
-    }
-
-    let pubkey_start = (packet_offsets.pubkey_start as usize)
-        .checked_sub(current_offset)
-        .ok_or(PacketError::InvalidLen)?;
-
-    let instructions_len_offset = (packet_offsets.pubkey_len as usize)
-        .checked_mul(size_of::<Pubkey>())
-        .and_then(|v| v.checked_add(pubkey_start))
-        .and_then(|v| v.checked_add(size_of::<Hash>()))
-        .ok_or(PacketError::InvalidLen)?;
-
-    // Packet should have at least 1 more byte for instructions.len
-    let _ = instructions_len_offset
-        .checked_add(1usize)
-        .filter(|v| *v <= packet.meta.size)
-        .ok_or(PacketError::InvalidLen)?;
-
-    let (instruction_len, instruction_len_size) =
-        decode_shortu16_len(&packet.data[instructions_len_offset..])
-            .map_err(|_| PacketError::InvalidLen)?;
-
-    // skip if has more than 1 instruction
-    if instruction_len != 1 {
-        return Err(PacketError::InvalidProgramLen);
-    }
-
-    let instruction_start = instructions_len_offset
-        .checked_add(instruction_len_size)
-        .ok_or(PacketError::InvalidLen)?;
-
-    // Packet should have at least 1 more byte for one instructions_program_id
-    let _ = instruction_start
-        .checked_add(1usize)
-        .filter(|v| *v <= packet.meta.size)
-        .ok_or(PacketError::InvalidLen)?;
-
-    let instruction_program_id_index: usize = usize::from(packet.data[instruction_start]);
-
-    if instruction_program_id_index >= packet_offsets.pubkey_len as usize {
-        return Err(PacketError::InvalidProgramIdIndex);
-    }
-
-    let instruction_program_id_start = instruction_program_id_index
-        .checked_mul(size_of::<Pubkey>())
-        .and_then(|v| v.checked_add(pubkey_start))
-        .ok_or(PacketError::InvalidLen)?;
-    let instruction_program_id_end = instruction_program_id_start
-        .checked_add(size_of::<Pubkey>())
-        .ok_or(PacketError::InvalidLen)?;
-
-    if &packet.data[instruction_program_id_start..instruction_program_id_end]
-        == solana_sdk::vote::program::id().as_ref()
-    {
-        packet.meta.is_simple_vote_tx = true;
-    }
-    Ok(())
-}
-
-pub fn generate_offsets(batches: &mut [Packets], recycler: &Recycler<TxOffset>) -> TxOffsets {
+pub fn generate_offsets(batches: &[Packets], recycler: &Recycler<TxOffset>) -> TxOffsets {
     debug!("allocating..");
-    let mut signature_offsets: PinnedVec<_> = recycler.allocate().unwrap();
+    let mut signature_offsets: PinnedVec<_> = recycler.allocate("sig_offsets");
     signature_offsets.set_pinnable();
-    let mut pubkey_offsets: PinnedVec<_> = recycler.allocate().unwrap();
+    let mut pubkey_offsets: PinnedVec<_> = recycler.allocate("pubkey_offsets");
     pubkey_offsets.set_pinnable();
-    let mut msg_start_offsets: PinnedVec<_> = recycler.allocate().unwrap();
+    let mut msg_start_offsets: PinnedVec<_> = recycler.allocate("msg_start_offsets");
     msg_start_offsets.set_pinnable();
-    let mut msg_sizes: PinnedVec<_> = recycler.allocate().unwrap();
+    let mut msg_sizes: PinnedVec<_> = recycler.allocate("msg_size_offsets");
     msg_sizes.set_pinnable();
     let mut current_offset: usize = 0;
     let mut v_sig_lens = Vec::new();
-    batches.iter_mut().for_each(|p| {
+    batches.iter().for_each(|p| {
         let mut sig_lens = Vec::new();
-        p.packets.iter_mut().for_each(|packet| {
+        p.packets.iter().for_each(|packet| {
             let packet_offsets = get_packet_offsets(packet, current_offset);
 
             sig_lens.push(packet_offsets.sig_len);
@@ -488,7 +405,7 @@ pub fn ed25519_verify(
 
     debug!("CUDA ECDSA for {}", batch_size(batches));
     debug!("allocating out..");
-    let mut out = recycler_out.allocate().unwrap();
+    let mut out = recycler_out.allocate("out_buffer");
     out.set_pinnable();
     let mut elems = Vec::new();
     let mut rvs = Vec::new();
@@ -552,11 +469,11 @@ mod tests {
     use crate::packet::{Packet, Packets};
     use crate::sigverify;
     use crate::sigverify::PacketOffsets;
-    use crate::test_tx::{test_multisig_tx, test_tx, vote_tx};
+    use crate::test_tx::{test_multisig_tx, test_tx};
     use bincode::{deserialize, serialize};
-    use solana_sdk::instruction::CompiledInstruction;
+    use solana_sdk::hash::Hash;
     use solana_sdk::message::{Message, MessageHeader};
-    use solana_sdk::signature::{Keypair, Signature};
+    use solana_sdk::signature::Signature;
     use solana_sdk::transaction::Transaction;
 
     const SIG_OFFSET: usize = 1;
@@ -578,9 +495,9 @@ mod tests {
         batch.packets.push(Packet::default());
         let mut batches: Vec<Packets> = vec![batch];
         mark_disabled(&mut batches, &[vec![0]]);
-        assert_eq!(batches[0].packets[0].meta.discard, true);
+        assert!(batches[0].packets[0].meta.discard);
         mark_disabled(&mut batches, &[vec![1]]);
-        assert_eq!(batches[0].packets[0].meta.discard, false);
+        assert!(!batches[0].packets[0].meta.discard);
     }
 
     #[test]
@@ -597,9 +514,9 @@ mod tests {
         let tx = test_tx();
         let tx_bytes = serialize(&tx).unwrap();
         let message_data = tx.message_data();
-        let mut packet = sigverify::make_packet_from_transaction(tx.clone());
+        let packet = sigverify::make_packet_from_transaction(tx.clone());
 
-        let packet_offsets = sigverify::get_packet_offsets(&mut packet, 0);
+        let packet_offsets = sigverify::get_packet_offsets(&packet, 0);
 
         assert_eq!(
             memfind(&tx_bytes, &tx.signatures[0].as_ref()),
@@ -680,65 +597,6 @@ mod tests {
         assert_eq!(res, Err(PacketError::InvalidLen));
     }
 
-    #[test]
-    fn test_pubkey_too_small() {
-        solana_logger::setup();
-        let mut tx = test_tx();
-        let sig = tx.signatures[0];
-        const NUM_SIG: usize = 18;
-        tx.signatures = vec![sig; NUM_SIG];
-        tx.message.account_keys = vec![];
-        tx.message.header.num_required_signatures = NUM_SIG as u8;
-        let mut packet = sigverify::make_packet_from_transaction(tx);
-
-        let res = sigverify::do_get_packet_offsets(&packet, 0);
-        assert_eq!(res, Err(PacketError::InvalidPubkeyLen));
-
-        verify_packet(&mut packet);
-        assert!(packet.meta.discard);
-
-        packet.meta.discard = false;
-        let mut batches = generate_packet_vec(&packet, 1, 1);
-        ed25519_verify(&mut batches);
-        assert!(batches[0].packets[0].meta.discard);
-    }
-
-    #[test]
-    fn test_pubkey_len() {
-        // See that the verify cannot walk off the end of the packet
-        // trying to index into the account_keys to access pubkey.
-        use solana_sdk::signer::{keypair::Keypair, Signer};
-        solana_logger::setup();
-
-        const NUM_SIG: usize = 17;
-        let keypair1 = Keypair::new();
-        let pubkey1 = keypair1.pubkey();
-        let mut message = Message::new(&[], Some(&pubkey1));
-        message.account_keys.push(pubkey1);
-        message.account_keys.push(pubkey1);
-        message.header.num_required_signatures = NUM_SIG as u8;
-        message.recent_blockhash = Hash(pubkey1.to_bytes());
-        let mut tx = Transaction::new_unsigned(message);
-
-        info!("message: {:?}", tx.message_data());
-        info!("tx: {:?}", tx);
-        let sig = keypair1.try_sign_message(&tx.message_data()).unwrap();
-        tx.signatures = vec![sig; NUM_SIG];
-
-        let mut packet = sigverify::make_packet_from_transaction(tx);
-
-        let res = sigverify::do_get_packet_offsets(&packet, 0);
-        assert_eq!(res, Err(PacketError::InvalidPubkeyLen));
-
-        verify_packet(&mut packet);
-        assert!(packet.meta.discard);
-
-        packet.meta.discard = false;
-        let mut batches = generate_packet_vec(&packet, 1, 1);
-        ed25519_verify(&mut batches);
-        assert!(batches[0].packets[0].meta.discard);
-    }
-
     #[test]
     fn test_large_sig_len() {
         let tx = test_tx();
@@ -823,14 +681,13 @@ mod tests {
 
     // Just like get_packet_offsets, but not returning redundant information.
     fn get_packet_offsets_from_tx(tx: Transaction, current_offset: u32) -> PacketOffsets {
-        let mut packet = sigverify::make_packet_from_transaction(tx);
-        let packet_offsets = sigverify::get_packet_offsets(&mut packet, current_offset as usize);
+        let packet = sigverify::make_packet_from_transaction(tx);
+        let packet_offsets = sigverify::get_packet_offsets(&packet, current_offset as usize);
         PacketOffsets::new(
             packet_offsets.sig_len,
             packet_offsets.sig_start - current_offset,
             packet_offsets.msg_start - packet_offsets.sig_start,
             packet_offsets.pubkey_start - packet_offsets.msg_start,
-            packet_offsets.pubkey_len,
         )
     }
 
@@ -838,23 +695,23 @@ mod tests {
     fn test_get_packet_offsets() {
         assert_eq!(
             get_packet_offsets_from_tx(test_tx(), 0),
-            PacketOffsets::new(1, 1, 64, 4, 2)
+            PacketOffsets::new(1, 1, 64, 4)
         );
         assert_eq!(
             get_packet_offsets_from_tx(test_tx(), 100),
-            PacketOffsets::new(1, 1, 64, 4, 2)
+            PacketOffsets::new(1, 1, 64, 4)
         );
 
         // Ensure we're not indexing packet by the `current_offset` parameter.
         assert_eq!(
             get_packet_offsets_from_tx(test_tx(), 1_000_000),
-            PacketOffsets::new(1, 1, 64, 4, 2)
+            PacketOffsets::new(1, 1, 64, 4)
         );
 
         // Ensure we're returning sig_len, not sig_size.
         assert_eq!(
             get_packet_offsets_from_tx(test_multisig_tx(), 0),
-            PacketOffsets::new(2, 1, 128, 4, 4)
+            PacketOffsets::new(2, 1, 128, 4)
         );
     }
 
@@ -891,8 +748,10 @@ mod tests {
 
         let mut batches = generate_packet_vec(&packet, n, 2);
 
+        let recycler = Recycler::default();
+        let recycler_out = Recycler::default();
         // verify packets
-        ed25519_verify(&mut batches);
+        sigverify::ed25519_verify(&mut batches, &recycler, &recycler_out);
 
         // check result
         let should_discard = modify_data;
@@ -902,12 +761,6 @@ mod tests {
             .all(|p| p.meta.discard == should_discard));
     }
 
-    fn ed25519_verify(batches: &mut [Packets]) {
-        let recycler = Recycler::new_without_limit("");
-        let recycler_out = Recycler::new_without_limit("");
-        sigverify::ed25519_verify(batches, &recycler, &recycler_out);
-    }
-
     #[test]
     fn test_verify_tampered_sig_len() {
         let mut tx = test_tx();
@@ -917,8 +770,10 @@ mod tests {
 
         let mut batches = generate_packet_vec(&packet, 1, 1);
 
+        let recycler = Recycler::default();
+        let recycler_out = Recycler::default();
         // verify packets
-        ed25519_verify(&mut batches);
+        sigverify::ed25519_verify(&mut batches, &recycler, &recycler_out);
         assert!(batches
             .iter()
             .flat_map(|p| &p.packets)
@@ -955,8 +810,10 @@ mod tests {
 
         batches[0].packets.push(packet);
 
+        let recycler = Recycler::default();
+        let recycler_out = Recycler::default();
         // verify packets
-        ed25519_verify(&mut batches);
+        sigverify::ed25519_verify(&mut batches, &recycler, &recycler_out);
 
         // check result
         let ref_ans = 1u8;
@@ -983,8 +840,8 @@ mod tests {
         let tx = test_multisig_tx();
         let packet = sigverify::make_packet_from_transaction(tx);
 
-        let recycler = Recycler::new_without_limit("");
-        let recycler_out = Recycler::new_without_limit("");
+        let recycler = Recycler::default();
+        let recycler_out = Recycler::default();
         for _ in 0..50 {
             let n = thread_rng().gen_range(1, 30);
             let num_batches = thread_rng().gen_range(2, 30);
@@ -1106,80 +963,4 @@ mod tests {
             failed_g.load(Ordering::Relaxed)
         );
     }
-
-    #[test]
-    fn test_is_simple_vote_transaction() {
-        solana_logger::setup();
-
-        // tansfer tx is not
-        {
-            let mut tx = test_tx();
-            tx.message.instructions[0].data = vec![1, 2, 3];
-            let mut packet = sigverify::make_packet_from_transaction(tx);
-            let packet_offsets = do_get_packet_offsets(&packet, 0).unwrap();
-            check_for_simple_vote_transaction(&mut packet, &packet_offsets, 0).ok();
-            assert!(!packet.meta.is_simple_vote_tx);
-        }
-
-        // single vote tx is
-        {
-            let mut tx = vote_tx();
-            tx.message.instructions[0].data = vec![1, 2, 3];
-            let mut packet = sigverify::make_packet_from_transaction(tx);
-            let packet_offsets = do_get_packet_offsets(&packet, 0).unwrap();
-            check_for_simple_vote_transaction(&mut packet, &packet_offsets, 0).ok();
-            assert!(packet.meta.is_simple_vote_tx);
-        }
-
-        // multiple mixed tx is not
-        {
-            let key = Keypair::new();
-            let key1 = Pubkey::new_unique();
-            let key2 = Pubkey::new_unique();
-            let tx = Transaction::new_with_compiled_instructions(
-                &[&key],
-                &[key1, key2],
-                Hash::default(),
-                vec![solana_vote_program::id(), Pubkey::new_unique()],
-                vec![
-                    CompiledInstruction::new(3, &(), vec![0, 1]),
-                    CompiledInstruction::new(4, &(), vec![0, 2]),
-                ],
-            );
-            let mut packet = sigverify::make_packet_from_transaction(tx);
-            let packet_offsets = do_get_packet_offsets(&packet, 0).unwrap();
-            check_for_simple_vote_transaction(&mut packet, &packet_offsets, 0).ok();
-            assert!(!packet.meta.is_simple_vote_tx);
-        }
-    }
-
-    #[test]
-    fn test_is_simple_vote_transaction_with_offsets() {
-        solana_logger::setup();
-
-        let mut current_offset = 0usize;
-        let mut batch = Packets::default();
-        batch
-            .packets
-            .push(sigverify::make_packet_from_transaction(test_tx()));
-        batch
-            .packets
-            .push(sigverify::make_packet_from_transaction(vote_tx()));
-        batch
-            .packets
-            .iter_mut()
-            .enumerate()
-            .for_each(|(index, mut packet)| {
-                let packet_offsets = do_get_packet_offsets(&packet, current_offset).unwrap();
-                check_for_simple_vote_transaction(&mut packet, &packet_offsets, current_offset)
-                    .ok();
-                if index == 1 {
-                    assert!(packet.meta.is_simple_vote_tx);
-                } else {
-                    assert!(!packet.meta.is_simple_vote_tx);
-                }
-
-                current_offset = current_offset.saturating_add(size_of::<Packet>());
-            });
-    }
 }
