@@ -5,7 +5,6 @@ use solana_sdk::system_instruction::SystemInstruction;
 use solana_sdk::system_program;
 use solana_sdk::system_transaction;
 use solana_sdk::transaction::Transaction;
-use solana_vote_program::vote_transaction;
 
 pub fn test_tx() -> Transaction {
     let keypair1 = Keypair::new();
@@ -23,7 +22,7 @@ pub fn test_multisig_tx() -> Transaction {
 
     let transfer_instruction = SystemInstruction::Transfer { lamports };
 
-    let program_ids = vec![system_program::id(), solana_budget_program::id()];
+    let program_ids = vec![system_program::id(), solana_stake_program::id()];
 
     let instructions = vec![CompiledInstruction::new(
         0,
@@ -39,16 +38,3 @@ pub fn test_multisig_tx() -> Transaction {
         instructions,
     )
 }
-
-pub fn vote_tx() -> Transaction {
-    let keypair = Keypair::new();
-    vote_transaction::new_vote_transaction(
-        vec![2],
-        Hash::default(),
-        Hash::default(),
-        &keypair,
-        &keypair,
-        &keypair,
-        None,
-    )
-}
